==> payara-embedded-all-5.193.1-sources.jar: com/sun/appserv/connectors/internal/spi/BadConnectionEventListener.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.appserv.connectors.internal.spi;

import javax.resource.spi.ConnectionEvent;

/**
 * Inteface for resource adapters to signal that the connection being closed is bad.
 * <i>Custom api</i>
 * @author  Jagadish Ramu
 */
public interface BadConnectionEventListener {

    /**
     * Error code used to indicate that the pool is reconfigured
     * and the client can retry to do operations based on
     * based on new configuration.
     * Used for <i>dynamic-resource-reconfiguration<i>
     */
    public static final String POOL_RECONFIGURED_ERROR_CODE = "POOL-RECONFIGURED-1";

    /**
     * Resource adapters will signal that the connection being closed is bad.
     * <i>Custom api</i>
     * @param evt ConnectionEvent
     */
    public void badConnectionClosed(ConnectionEvent evt);

    /**
     * Resource adapters will signal that the connection is being aborted.
     * @param evt ConnectionEvent
     */
    public void connectionAbortOccurred(ConnectionEvent evt);
}

==> payara-embedded-all-6.2023.6-sources.jar: com/sun/appserv/connectors/internal/spi/BadConnectionEventListener.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.appserv.connectors.internal.spi;

import jakarta.resource.spi.ConnectionEvent;

/**
 * Inteface for resource adapters to signal that the connection being closed is bad.
 * <i>Custom api</i>
 * @author  Jagadish Ramu
 */
public interface BadConnectionEventListener {

    /**
     * Error code used to indicate that the pool is reconfigured
     * and the client can retry to do operations based on
     * based on new configuration.
     * Used for <i>dynamic-resource-reconfiguration<i>
     */
    public static final String POOL_RECONFIGURED_ERROR_CODE = "POOL-RECONFIGURED-1";

    /**
     * Resource adapters will signal that the connection being closed is bad.
     * <i>Custom api</i>
     * @param evt ConnectionEvent
     */
    public void badConnectionClosed(ConnectionEvent evt);

    /**
     * Resource adapters will signal that the connection is being aborted.
     * @param evt ConnectionEvent
     */
    public void connectionAbortOccurred(ConnectionEvent evt);
}
